/*
** Module   : XDocumentImpl
** Abstract : DOM XML Document resource type implementation.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 EVL 20130130 Created initial version.
*/

package com.goldencode.p2j.xml;

import java.io.*;
import org.w3c.dom.*;
import com.goldencode.p2j.util.*;
import com.goldencode.util.XmlHelper;

/**
 */
public class XDocumentImpl
extends XEntityImpl
implements XDocument
{
   /** The real document to assign with handle  */
   private Document xdoc = null;
   
   private XNodeRefImpl xRootNode = null;

   /**
    * Default constructor.
    */
   public XDocumentImpl()
   {
      super();
      try
      {
         xdoc = XmlHelper.newDocument();
      }
      catch (Exception e)
      {
         // TODO: change this
         xdoc = null;
      }
      xRootNode = new XNodeRefImpl();
   }

   // Methods
   // Returning value placed into hChild
   public logical createNode(handle hChild, String name, String type)
   {
      return createNode(hChild, new character(name), new character(type));
   }

   public logical createNode(handle hChild, character name, String type)
   {
      return createNode(hChild, name, new character(type));
   }

   public logical createNode(handle hChild, String name, character type)
   {
      return createNode(hChild, new character(name), type);
   }

   public logical createNode(handle hChild, character name, character type)
   {
      logical res = new logical(true);
      
      hChild = XmlFactory.createXNodeReference();
      xRootNode.appendChild(hChild, name, type);
      
      return res;
   }

   public logical createNodeNamespace(handle hChild, String uri,
                                      String name, String type)
   {
      return createNodeNamespace(hChild, new character(uri),
                                 new character(name), new character(type));
   }
   
   public logical createNodeNamespace(handle hChild, character uri,
                                      String name, String type)
   {
      return createNodeNamespace(hChild, uri, new character(name),
                                 new character(type));
   }
   
   public logical createNodeNamespace(handle hChild, String uri,
                                      character name, String type)
   {
      return createNodeNamespace(hChild, new character(uri), name,
                                 new character(type));
   }
   
   public logical createNodeNamespace(handle hChild, String uri,
                                      String name, character type)
   {
      return createNodeNamespace(hChild, new character(uri),
                                 new character(name), type);
   }
   
   public logical createNodeNamespace(handle hChild, String uri,
                                      character name, character type)
   {
      return createNodeNamespace(hChild, new character(uri), name, type);
   }
   
   public logical createNodeNamespace(handle hChild, character uri,
                                      String name, character type)
   {
      return createNodeNamespace(hChild, uri, new character(name), type);
   }
   
   public logical createNodeNamespace(handle hChild, character uri,
                                      character name, String type)
   {
      return createNodeNamespace(hChild, uri, name, new character(type));
   }
   
   public logical createNodeNamespace(handle hChild, character uri,
                                      character name, character type)
   {
      // TODO: Implementation here
      logical res = new logical(false);
      
      return res;
   }
   
   // Returning value placed into hRoot
   public logical getDocumentElement(handle hRoot)
   {
      hRoot = getHandle();
      if(isValid())
         return new logical(true);
      else
         return new logical(false);
   }
   
   public logical load(String mode, Object source, logical validate)
   {
      return load(new character(mode), source, validate);
   }
   
   public logical load(String mode, Object source, boolean validate)
   {
      return load(new character(mode), source, new logical(validate));
   }
   
   public logical load(character mode, Object source, boolean validate)
   {
      return load(mode, source, new logical(validate));
   }
   
   public logical load(character mode, Object source, logical validate)
   {
      // TODO: Implementation here
      logical res = new logical(false);
      
      return res;
   }
   
   public logical save(String mode, Object target)
   {
      return save(new character(mode), target);
   }
   
   public logical save(character mode, Object target)
   {
      String writeMode = mode.getValue();
      if(writeMode.equals("FILE"))
         try
         {
            XmlHelper.write(xdoc, (String)target);
         }
         catch(IOException ioe)
         {
         }
      else if(writeMode.equals("STREAM"))
         try
         {
            XmlHelper.write(xdoc, (OutputStream)target);
         }
         catch(IOException ioe)
         {
         }
      else if(writeMode.equals("MEMPTR"))
        return new logical(false);
      else
        return new logical(false);
      
      return new logical(true);
   }
}
