/*
** Module   : XNodeRefImpl
** Abstract : DOM XML Node reference resource type implementation.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 EVL 20130130 Created initial version.
*/

package com.goldencode.p2j.xml;

import java.util.*;
import org.w3c.dom.*;
import com.goldencode.p2j.util.*;

/**
 */
public class XNodeRefImpl
extends XEntityImpl
implements XNodeRef
{
   /** List of child node names */
   private Map<character, character> attributeNameList;

   /**
    * Default constructor.
    */
   public XNodeRefImpl()
   {
      super();
      attributeNameList  = Collections.synchronizedMap(new LinkedHashMap<character, character>());
   }

   // Attributes
   public character getAttributeNames()
   {
      StringBuilder sb = new StringBuilder();
      
      Set keySet = attributeNameList.keySet();
      Iterator iter = keySet.iterator();
      while(iter.hasNext())
      {
         character chEntry = (character)iter.next();
         sb.append(chEntry.getValue());
         if(iter.hasNext())
            sb.append(",");
      }
      
      return new character(sb.toString());
   }
   
   public handle getOwnerDocument()
   {
      return getHandle();
   }
   
   // Methods
   public logical deleteNode()
   {
      clear();
      attributeNameList.clear();
      
      return new logical(true);
   }
   
   public character getAttribute(String name)
   {
      return getAttribute(new character(name));
   }
   
   public character getAttribute(character name)
   {
      return (character)attributeNameList.get(name);
   }
   
   public logical setAttribute(String name, String value)
   {
      return setAttribute(new character(name), new character(value));
   }
   
   public logical setAttribute(String name, character value)
   {
      return setAttribute(new character(name), value);
   }
   
   public logical setAttribute(character name, String value)
   {
      return setAttribute(name, new character(value));
   }
   
   public logical setAttribute(character name, character value)
   {
      logical res = new logical(true);
      
      attributeNameList.put(name, value);
      
      return res;
   }
}
